SessionEventColor enum Configuration
Represents the color options for session events in Crisp chat. This enum is used to categorize events visually in the chat interface. Each color corresponds to a specific color used in the Crisp chat UI. The colors are used to differentiate events and provide a visual cue to users and support agents.
Values
- black → const SessionEventColor
- blue → const SessionEventColor
- brown → const SessionEventColor
- green → const SessionEventColor
- grey → const SessionEventColor
- orange → const SessionEventColor
- pink → const SessionEventColor
- purple → const SessionEventColor
- red → const SessionEventColor
- yellow → const SessionEventColor
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SessionEventColor> - A constant List of the values in this enum, in order of their declaration.